// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KDAV2_VERSION_H
#define KDAV2_VERSION_H

#define KDAV2_VERSION_STRING "0.4.0"
#define KDAV2_VERSION_MAJOR 0
#define KDAV2_VERSION_MINOR 4
#define KDAV2_VERSION_PATCH 0
#define KDAV2_VERSION ((0<<16)|(4<<8)|(0))

#endif
